From 85bcdbad468cd255a02d6c48b2dcd1d128978eed Mon Sep 17 00:00:00 2001
From: Igor Wiedler <igor@wiedler.ch>
Date: Sat, 21 Jul 2012 16:19:01 +0200
Subject: [ticket/11012] Normalize $phpEx member vars to $php_ext

PHPBB3-11012
---
 phpBB/includes/extension/controller.php |  6 +++---
 phpBB/includes/extension/finder.php     | 14 +++++++-------
 phpBB/includes/extension/manager.php    | 14 +++++++-------
 3 files changed, 17 insertions(+), 17 deletions(-)

(limited to 'phpBB/includes/extension')

diff --git a/phpBB/includes/extension/controller.php b/phpBB/includes/extension/controller.php
index c7fd439a19..ec051c756f 100644
--- a/phpBB/includes/extension/controller.php
+++ b/phpBB/includes/extension/controller.php
@@ -50,7 +50,7 @@ abstract class phpbb_extension_controller implements phpbb_extension_controller_
 	/**
 	* @var string PHP Extension
 	*/
-	protected $phpEx;
+	protected $php_ext;
 
 	/**
 	* @var string Relative path to board root
@@ -64,14 +64,14 @@ abstract class phpbb_extension_controller implements phpbb_extension_controller_
 	public function __construct()
 	{
 		global $request, $db, $user, $template, $config;
-		global $phpEx, $phpbb_root_path;
+		global $php_ext, $phpbb_root_path;
 
 		$this->request = $request;
 		$this->db = $db;
 		$this->user = $user;
 		$this->template = $template;
 		$this->config = $config;
-		$this->phpEx = $phpEx;
+		$this->php_ext = $php_ext;
 		$this->phpbb_root_path = $phpbb_root_path;
 	}
 }
diff --git a/phpBB/includes/extension/finder.php b/phpBB/includes/extension/finder.php
index 87ca40917d..fb19b98429 100644
--- a/phpBB/includes/extension/finder.php
+++ b/phpBB/includes/extension/finder.php
@@ -25,7 +25,7 @@ class phpbb_extension_finder
 	protected $extension_manager;
 	protected $phpbb_root_path;
 	protected $cache;
-	protected $phpEx;
+	protected $php_ext;
 
 	/**
 	* The cache variable name used to store $this->cached_queries in $this->cache.
@@ -56,16 +56,16 @@ class phpbb_extension_finder
 	*            extensions and their locations
 	* @param string $phpbb_root_path Path to the phpbb root directory
 	* @param phpbb_cache_driver_interface $cache A cache instance or null
 	* @param string $phpEx php file extension
 	* @param string $cache_name The name of the cache variable, defaults to
 	*                           _ext_finder
 	*/
-	public function __construct(phpbb_extension_manager $extension_manager, $phpbb_root_path = '', phpbb_cache_driver_interface $cache = null, $phpEx = '.php', $cache_name = '_ext_finder')
+	public function __construct(phpbb_extension_manager $extension_manager, $phpbb_root_path = '', phpbb_cache_driver_interface $cache = null, $php_ext = '.php', $cache_name = '_ext_finder')
 	{
 		$this->extension_manager = $extension_manager;
 		$this->phpbb_root_path = $phpbb_root_path;
 		$this->cache = $cache;
-		$this->phpEx = $phpEx;
+		$this->php_ext = $php_ext;
 		$this->cache_name = $cache_name;
 
 		$this->query = array(
@@ -251,8 +251,8 @@ class phpbb_extension_finder
 	*/
 	public function get_classes($cache = true)
 	{
-		$this->query['extension_suffix'] .= $this->phpEx;
-		$this->query['core_suffix'] .= $this->phpEx;
+		$this->query['extension_suffix'] .= $this->php_ext;
+		$this->query['core_suffix'] .= $this->php_ext;
 
 		$files = $this->find($cache, false);
 
@@ -261,7 +261,7 @@ class phpbb_extension_finder
 		{
 			$file = preg_replace('#^includes/#', '', $file);
 
-			$classes[] = 'phpbb_' . str_replace('/', '_', substr($file, 0, -strlen($this->phpEx)));
+			$classes[] = 'phpbb_' . str_replace('/', '_', substr($file, 0, -strlen($this->php_ext)));
 		}
 		return $classes;
 	}
@@ -56,16 +56,16 @@ class phpbb_extension_finder
 	* @param string $phpbb_root_path Path to the phpbb root directory
 	* @param phpbb_cache_driver_interface $cache A cache instance or null
-	* @param string $phpEx php file extension
+	* @param string $php_ext php file extension
 	* @param string $cache_name The name of the cache variable, defaults to
 	*                           _ext_finder
diff --git a/phpBB/includes/extension/manager.php b/phpBB/includes/extension/manager.php
index 537c19aff8..86d8fab64b 100644
--- a/phpBB/includes/extension/manager.php
+++ b/phpBB/includes/extension/manager.php
@@ -23,7 +23,7 @@ if (!defined('IN_PHPBB'))
 class phpbb_extension_manager
 {
 	protected $cache;
-	protected $phpEx;
+	protected $php_ext;
 	protected $extensions;
 	protected $extension_table;
 	protected $phpbb_root_path;
@@ -35,16 +35,16 @@ class phpbb_extension_manager
 	* @param dbal $db A database connection
 	* @param string $extension_table The name of the table holding extensions
 	* @param string $phpbb_root_path Path to the phpbb includes directory.
 	* @param string $phpEx php file extension
 	* @param phpbb_cache_driver_interface $cache A cache instance or null
 	* @param string $cache_name The name of the cache variable, defaults to _ext
 	*/
-	public function __construct(dbal $db, $extension_table, $phpbb_root_path, $phpEx = '.php', phpbb_cache_driver_interface $cache = null, $cache_name = '_ext')
+	public function __construct(dbal $db, $extension_table, $phpbb_root_path, $php_ext = '.php', phpbb_cache_driver_interface $cache = null, $cache_name = '_ext')
 	{
 		$this->phpbb_root_path = $phpbb_root_path;
 		$this->db = $db;
 		$this->cache = $cache;
-		$this->phpEx = $phpEx;
+		$this->php_ext = $php_ext;
 		$this->extension_table = $extension_table;
 		$this->cache_name = $cache_name;
 
@@ -362,7 +362,7 @@ class phpbb_extension_manager
 			RecursiveIteratorIterator::SELF_FIRST);
 		foreach ($iterator as $file_info)
 		{
-			if ($file_info->isFile() && $file_info->getFilename() == 'ext' . $this->phpEx)
+			if ($file_info->isFile() && $file_info->getFilename() == 'ext' . $this->php_ext)
 			{
 				$ext_name = $iterator->getInnerIterator()->getSubPath();
 
@@ -432,7 +432,7 @@ class phpbb_extension_manager
 		}
 		return $disabled;
 	}
-	
+
 	/**
 	* Check to see if a given extension is available on the filesystem
 	*
@@ -462,6 +462,6 @@ class phpbb_extension_manager
 	*/
 	public function get_finder()
 	{
-		return new phpbb_extension_finder($this, $this->phpbb_root_path, $this->cache, $this->phpEx, $this->cache_name . '_finder');
+		return new phpbb_extension_finder($this, $this->phpbb_root_path, $this->cache, $this->php_ext, $this->cache_name . '_finder');
 	}
 }
@@ -35,16 +35,16 @@ class phpbb_extension_manager
 	* @param string $extension_table The name of the table holding extensions
 	* @param string $phpbb_root_path Path to the phpbb includes directory.
-	* @param string $phpEx php file extension
+	* @param string $php_ext php file extension
 	* @param phpbb_cache_driver_interface $cache A cache instance or null
 	* @param string $cache_name The name of the cache variable, defaults to _ext
-- 
cgit v1.2.1